@@ -104,9 +104,10 @@ class Remove_duplicate_time(object):
                 if point['time'] not in t:
                     new_stroke.append(point)
                     t.append(point['time'])
-            new_pointlist.append(new_stroke)
+            if len(new_stroke) > 0:
+                new_pointlist.append(new_stroke)
         # Make sure there are no duplicates
-        times = [point['time'] for point in pointlist for stroke in pointlist]
+        times = [point['time'] for point in stroke for stroke in pointlist]
         assert len(times) == len(set(times)), \
             ("The list of all times in Remove_duplicate_time has %i values, "
              "but the set has %i values.") % (len(times), len(set(times)))
